weco-deploy
===========

A tool for deploying ECS services at the Wellcome Collection.

.. image:: https://travis-ci.org/wellcomecollection/weco-deploy.svg?branch=master
    :target: https://travis-ci.org/wellcomecollection/weco-deploy
